You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@stanbol.apache.org by co...@apache.org on 2011/03/25 15:15:32 UTC

svn commit: r1085388 - in /incubator/stanbol/trunk/kres/reasoners/web: ./ src/main/java/org/apache/stanbol/reasoners/web/

Author: concelvio
Date: Fri Mar 25 14:15:32 2011
New Revision: 1085388

URL: http://svn.apache.org/viewvc?rev=1085388&view=rev
Log:
STANBOL-39:
- changed parent version in pom.xml to ${stanbol-version}
- removed kres-version from pom.xml
- change class reference where requiredpom.xml

Modified:
    incubator/stanbol/trunk/kres/reasoners/web/pom.xml
    incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Classify.java
    incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/ConsistencyCheck.java
    incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Enrichment.java

Modified: incubator/stanbol/trunk/kres/reasoners/web/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/kres/reasoners/web/pom.xml?rev=1085388&r1=1085387&r2=1085388&view=diff
==============================================================================
--- incubator/stanbol/trunk/kres/reasoners/web/pom.xml (original)
+++ incubator/stanbol/trunk/kres/reasoners/web/pom.xml Fri Mar 25 14:15:32 2011
@@ -1,4 +1,19 @@
 <?xml version="1.0" encoding="UTF-8"?>
+	<!--
+		Licensed to the Apache Software Foundation (ASF) under one or more
+		contributor license agreements. See the NOTICE file distributed with
+		this work for additional information regarding copyright ownership.
+		The ASF licenses this file to You under the Apache License, Version
+		2.0 (the "License"); you may not use this file except in compliance
+		with the License. You may obtain a copy of the License at
+
+		http://www.apache.org/licenses/LICENSE-2.0 Unless required by
+		applicable law or agreed to in writing, software distributed under the
+		License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
+		CONDITIONS OF ANY KIND, either express or implied. See the License for
+		the specific language governing permissions and limitations under the
+		License.
+	-->
 <project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
 	xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
 
@@ -7,8 +22,8 @@
 	<parent>
 		<groupId>org.apache.stanbol</groupId>
 		<artifactId>stanbol-parent</artifactId>
-		<version>0.9-SNAPSHOT</version>
-		<relativePath>../../parent</relativePath>
+		<version>${stanbol-version}</version>
+		<relativePath>../../../parent</relativePath>
 	</parent>
 
 	<groupId>org.apache.stanbol</groupId>
@@ -19,10 +34,6 @@
 	<name>Apache Stanbol Reasoner Web</name>
 	<description>Set of rest services to deal with reasoners</description>
 
-	<properties>
-		<kres-version>0.7</kres-version>
-	</properties>
-
 	<dependencies>
 
 		<!-- dependencies on other IKS modules -->
@@ -197,14 +208,6 @@
 			<scope>test</scope>
 		</dependency>
 
-
-		<!-- KReS -->
-		<!--
-			<dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.api</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency>
-		-->
 		<dependency>
 			<groupId>org.apache.stanbol</groupId>
 			<artifactId>org.apache.stanbol.ontologymanager.ontonet</artifactId>
@@ -253,30 +256,6 @@
 			<scope>provided</scope>
 		</dependency>
 
-		<!--
-			<dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.manager</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency> <dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.rules</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency> <dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.semion.manager</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency> <dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.semion.refactorer</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency>
-		-->
-		<!--
-			<dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.reasoners</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency> <dependency> <groupId>eu.iksproject</groupId>
-			<artifactId>eu.iksproject.kres.storage.provider</artifactId>
-			<version>${kres-version}</version> <scope>provided</scope>
-			</dependency>
-		-->
 		<dependency>
 			<groupId>com.hp.hpl.jena</groupId>
 			<artifactId>jena</artifactId>

Modified: incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Classify.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Classify.java?rev=1085388&r1=1085387&r2=1085388&view=diff
==============================================================================
--- incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/ConsistencyCheck.java (original)
+++ incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/ConsistencyCheck.java Fri Mar 25 14:15:32 2011
@@ -22,24 +22,24 @@ import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
 
 import org.apache.clerezza.rdf.core.access.TcManager;
-import org.apache.stanbol.ontologymanager.ontonet.api.KReSONManager;
+import org.apache.stanbol.ontologymanager.ontonet.api.ONManager;
 import org.apache.stanbol.ontologymanager.ontonet.api.OWLDuplicateSafeLoader;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.OntologyScope;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.OntologySpace;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.ScopeRegistry;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.SessionOntologySpace;
-import org.apache.stanbol.ontologymanager.ontonet.impl.ONManager;
+import org.apache.stanbol.ontologymanager.ontonet.impl.ONManagerImpl;
 import org.apache.stanbol.ontologymanager.ontonet.impl.ontology.OntologyStorage;
-import org.apache.stanbol.reasoners.base.commands.KReSCreateReasoner;
-import org.apache.stanbol.reasoners.base.commands.KReSRunReasoner;
-import org.apache.stanbol.reasoners.base.commands.KReSRunRules;
-import org.apache.stanbol.rules.base.api.KReSRule;
+import org.apache.stanbol.reasoners.base.commands.CreateReasoner;
+import org.apache.stanbol.reasoners.base.commands.RunReasoner;
+import org.apache.stanbol.reasoners.base.commands.RunRules;
+import org.apache.stanbol.rules.base.api.Rule;
 import org.apache.stanbol.rules.base.api.NoSuchRecipeException;
 import org.apache.stanbol.rules.base.api.RuleStore;
-import org.apache.stanbol.rules.base.api.util.KReSRuleList;
-import org.apache.stanbol.rules.manager.KReSKB;
-import org.apache.stanbol.rules.manager.changes.KReSRuleStore;
-import org.apache.stanbol.rules.manager.parse.KReSRuleParser;
+import org.apache.stanbol.rules.base.api.util.RuleList;
+import org.apache.stanbol.rules.manager.KB;
+import org.apache.stanbol.rules.manager.changes.RuleStoreImpl;
+import org.apache.stanbol.rules.manager.parse.RuleParserImpl;
 import org.semanticweb.owlapi.apibinding.OWLManager;
 import org.semanticweb.owlapi.model.AddImport;
 import org.semanticweb.owlapi.model.IRI;
@@ -78,7 +78,7 @@ public class ConsistencyCheck {
 	private OWLOntology scopeowl;
 
 	private final OWLDuplicateSafeLoader loader = new OWLDuplicateSafeLoader();
-	protected KReSONManager onm;
+	protected ONManager onm;
 	protected OntologyStorage storage;
 
 	private Logger log = LoggerFactory.getLogger(getClass());
@@ -95,8 +95,8 @@ public class ConsistencyCheck {
 		this.kresRuleStore = (RuleStore) servletContext
 				.getAttribute(RuleStore.class.getName());
 		// Retrieve the ontology network manager
-		this.onm = (KReSONManager) servletContext
-				.getAttribute(KReSONManager.class.getName());
+		this.onm = (ONManager) servletContext
+				.getAttribute(ONManager.class.getName());
 //      this.storage = (OntologyStorage) servletContext
 //      .getAttribute(OntologyStorage.class.getName());
 // Contingency code for missing components follows.
@@ -107,7 +107,7 @@ public class ConsistencyCheck {
 if (onm == null) {
     log
             .warn("No KReSONManager in servlet context. Instantiating manually...");
-    onm = new ONManager(new TcManager(), null,
+    onm = new ONManagerImpl(new TcManager(), null,
             new Hashtable<String, Object>());
 }
 this.storage = onm.getOntologyStore();
@@ -118,7 +118,7 @@ if (storage == null) {
 		if (kresRuleStore == null) {
 			log
 					.warn("No KReSRuleStore with stored rules and recipes found in servlet context. Instantiating manually with default values...");
-			this.kresRuleStore = new KReSRuleStore(onm,
+			this.kresRuleStore = new RuleStoreImpl(onm,
 					new Hashtable<String, Object>(), "");
 			log
 					.debug("PATH TO OWL FILE LOADED: "
@@ -138,7 +138,7 @@ if (storage == null) {
 			throws NoSuchRecipeException, OWLOntologyCreationException {
 
 		// FIXME: why the heck is this method re-instantiating a rule store?!?
-		RuleStore store = new KReSRuleStore(onm,
+		RuleStore store = new RuleStoreImpl(onm,
 				new Hashtable<String, Object>(), owl);
 		Model jenamodel = ModelFactory.createDefaultModel();
 
@@ -174,11 +174,11 @@ if (storage == null) {
 
 		// kReSRules =
 		// "ProvaParent = <http://www.semanticweb.org/ontologies/2010/6/ProvaParent.owl#> . rule1[ has(ProvaParent:hasParent, ?x, ?y) . has(ProvaParent:hasBrother, ?y, ?z) -> has(ProvaParent:hasUncle, ?x, ?z) ]";
-		KReSKB kReSKB = KReSRuleParser.parse(kReSRules);
-		KReSRuleList listrules = kReSKB.getkReSRuleList();
-		Iterator<KReSRule> iterule = listrules.iterator();
+		KB kReSKB = RuleParserImpl.parse(kReSRules);
+		RuleList listrules = kReSKB.getkReSRuleList();
+		Iterator<Rule> iterule = listrules.iterator();
 		while (iterule.hasNext()) {
-			KReSRule singlerule = iterule.next();
+			Rule singlerule = iterule.next();
 			Resource resource = singlerule.toSWRL(jenamodel);
 		}
 
@@ -229,10 +229,10 @@ if (storage == null) {
 								ee);
 				return Response.status(Status.NOT_FOUND).build();
 			}
-			KReSCreateReasoner newreasoner = new KReSCreateReasoner(owl);
+			CreateReasoner newreasoner = new CreateReasoner(owl);
 			// KReSReasonerImpl reasoner = new KReSReasonerImpl();
 			try {
-				KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+				RunReasoner reasoner = new RunReasoner(newreasoner
 						.getReasoner());
 				ok = reasoner.isConsistent();
 			} catch (InconsistentOntologyException exc) {
@@ -443,16 +443,16 @@ if (storage == null) {
 						Model swrlmodel = fromRecipeToModel(recipeowl);
 						// Create a reasoner to run rules contained in the
 						// recipe
-						KReSRunRules rulereasoner = new KReSRunRules(swrlmodel,
+						RunRules rulereasoner = new RunRules(swrlmodel,
 								inputowl);
 						// Run the rule reasoner to the input RDF with the added
 						// top-ontology
 						inputowl = rulereasoner.runRulesReasoner();
 					}
-					KReSCreateReasoner newreasoner = new KReSCreateReasoner(
+					CreateReasoner newreasoner = new CreateReasoner(
 							inputowl);
 					// Prepare and start the reasoner to check the consistence
-					KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+					RunReasoner reasoner = new RunReasoner(newreasoner
 							.getReasoner());
 					ok = reasoner.isConsistent();
 				} catch (InconsistentOntologyException exc) {
@@ -485,17 +485,17 @@ if (storage == null) {
 
 						// Create a reasoner to run rules contained in the
 						// recipe by using the server and-point
-						KReSRunRules rulereasoner = new KReSRunRules(swrlmodel,
+						RunRules rulereasoner = new RunRules(swrlmodel,
 								inputowl, new URL(owllink_endpoint));
 						// Run the rule reasoner to the input RDF with the added
 						// top-ontology
 						inputowl = rulereasoner.runRulesReasoner();
 					}
 
-					KReSCreateReasoner newreasoner = new KReSCreateReasoner(
+					CreateReasoner newreasoner = new CreateReasoner(
 							inputowl, new URL(owllink_endpoint));
 					// Prepare and start the reasoner to check the consistence
-					KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+					RunReasoner reasoner = new RunReasoner(newreasoner
 							.getReasoner());
 					ok = reasoner.isConsistent();
 				} catch (InconsistentOntologyException exc) {

Modified: incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Enrichment.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Enrichment.java?rev=1085388&r1=1085387&r2=1085388&view=diff
==============================================================================
--- incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Classify.java (original)
+++ incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Classify.java Fri Mar 25 14:15:32 2011
@@ -26,23 +26,23 @@ import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
 
 import org.apache.clerezza.rdf.core.access.TcManager;
-import org.apache.stanbol.ontologymanager.ontonet.api.KReSONManager;
+import org.apache.stanbol.ontologymanager.ontonet.api.ONManager;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.OntologyScope;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.OntologySpace;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.ScopeRegistry;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.SessionOntologySpace;
-import org.apache.stanbol.ontologymanager.ontonet.impl.ONManager;
+import org.apache.stanbol.ontologymanager.ontonet.impl.ONManagerImpl;
 import org.apache.stanbol.ontologymanager.ontonet.impl.ontology.OntologyStorage;
-import org.apache.stanbol.reasoners.base.commands.KReSCreateReasoner;
-import org.apache.stanbol.reasoners.base.commands.KReSRunReasoner;
-import org.apache.stanbol.reasoners.base.commands.KReSRunRules;
-import org.apache.stanbol.rules.base.api.KReSRule;
+import org.apache.stanbol.reasoners.base.commands.CreateReasoner;
+import org.apache.stanbol.reasoners.base.commands.RunReasoner;
+import org.apache.stanbol.reasoners.base.commands.RunRules;
+import org.apache.stanbol.rules.base.api.Rule;
 import org.apache.stanbol.rules.base.api.NoSuchRecipeException;
 import org.apache.stanbol.rules.base.api.RuleStore;
-import org.apache.stanbol.rules.base.api.util.KReSRuleList;
-import org.apache.stanbol.rules.manager.KReSKB;
-import org.apache.stanbol.rules.manager.changes.KReSRuleStore;
-import org.apache.stanbol.rules.manager.parse.KReSRuleParser;
+import org.apache.stanbol.rules.base.api.util.RuleList;
+import org.apache.stanbol.rules.manager.KB;
+import org.apache.stanbol.rules.manager.changes.RuleStoreImpl;
+import org.apache.stanbol.rules.manager.parse.RuleParserImpl;
 import org.semanticweb.owlapi.apibinding.OWLManager;
 import org.semanticweb.owlapi.model.AddImport;
 import org.semanticweb.owlapi.model.IRI;
@@ -77,13 +77,13 @@ public class Classify {
      private OWLOntology inputowl;
      private OWLOntology scopeowl;
 
-	protected KReSONManager onm;
+	protected ONManager onm;
 	protected OntologyStorage storage;
 
 	private Logger log = LoggerFactory.getLogger(getClass());
 
     /**
      * To get the KReSRuleStore where are stored the rules and the recipes
      *
 	 * @param servletContext
 	 *            {To get the context where the REST service is running.}
@@ -91,8 +91,8 @@ public class Classify {
     public Classify(@Context ServletContext servletContext){
 		this.kresRuleStore = (RuleStore) servletContext
 				.getAttribute(RuleStore.class.getName());
-		this.onm = (KReSONManager) servletContext
-				.getAttribute(KReSONManager.class.getName());
+		this.onm = (ONManager) servletContext
+				.getAttribute(ONManager.class.getName());
 //      this.storage = (OntologyStorage) servletContext
 //      .getAttribute(OntologyStorage.class.getName());
 // Contingency code for missing components follows.
@@ -103,7 +103,7 @@ public class Classify {
 if (onm == null) {
     log
             .warn("No KReSONManager in servlet context. Instantiating manually...");
-    onm = new ONManager(new TcManager(), null,
+    onm = new ONManagerImpl(new TcManager(), null,
             new Hashtable<String, Object>());
 }
 this.storage = onm.getOntologyStore();
@@ -114,7 +114,7 @@ if (storage == null) {
        if (kresRuleStore == null) {
 			log
 					.warn("No KReSRuleStore with stored rules and recipes found in servlet context. Instantiating manually with default values...");
-			this.kresRuleStore = new KReSRuleStore(onm,
+			this.kresRuleStore = new RuleStoreImpl(onm,
 					new Hashtable<String, Object>(), "");
 			log
 					.debug("PATH TO OWL FILE LOADED: "
@@ -133,7 +133,7 @@ if (storage == null) {
 			throws NoSuchRecipeException {
 
 		// FIXME: why the heck is this method re-instantiating a rule store?!?
-		RuleStore store = new KReSRuleStore(onm,
+		RuleStore store = new RuleStoreImpl(onm,
 				new Hashtable<String, Object>(), owl);
         Model jenamodel = ModelFactory.createDefaultModel();
 
@@ -169,11 +169,11 @@ if (storage == null) {
 		}
 
 	//"ProvaParent = <http://www.semanticweb.org/ontologies/2010/6/ProvaParent.owl#> . rule1[ has(ProvaParent:hasParent, ?x, ?y) . has(ProvaParent:hasBrother, ?y, ?z) -> has(ProvaParent:hasUncle, ?x, ?z) ]");
-        KReSKB kReSKB = KReSRuleParser.parse(kReSRules);
-        KReSRuleList listrules = kReSKB.getkReSRuleList();
-        Iterator<KReSRule> iterule = listrules.iterator();
+        KB kReSKB = RuleParserImpl.parse(kReSRules);
+        RuleList listrules = kReSKB.getkReSRuleList();
+        Iterator<Rule> iterule = listrules.iterator();
         while(iterule.hasNext()){
-            KReSRule singlerule = iterule.next();
+            Rule singlerule = iterule.next();
             Resource resource = singlerule.toSWRL(jenamodel);
         }
 
@@ -368,7 +368,7 @@ if (storage == null) {
 
 						// Create a reasoner to run rules contained in the
 						// recipe
-						KReSRunRules rulereasoner = new KReSRunRules(swrlmodel,
+						RunRules rulereasoner = new RunRules(swrlmodel,
 								inputowl);
 						// Run the rule reasoner to the input RDF with the added
 						// top-ontology
@@ -376,11 +376,11 @@ if (storage == null) {
        }
 
             //Create the reasoner for the classification
-					KReSCreateReasoner newreasoner = new KReSCreateReasoner(
+					CreateReasoner newreasoner = new CreateReasoner(
 							inputowl);
 					// Prepare and start the reasoner to classify ontology's
 					// resources
-					KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+					RunReasoner reasoner = new RunReasoner(newreasoner
 							.getReasoner());
 
 					// Create a new OWLOntology model where to put the inferred
@@ -422,7 +422,7 @@ if (storage == null) {
          Model swrlmodel = fromRecipeToModel(recipeowl);
 						// Create a reasoner to run rules contained in the
 						// recipe by using the server and-point
-						KReSRunRules rulereasoner = new KReSRunRules(swrlmodel,
+						RunRules rulereasoner = new RunRules(swrlmodel,
 								inputowl, new URL(owllink_endpoint));
 						// Run the rule reasoner to the input RDF with the added
 						// top-ontology
@@ -430,11 +430,11 @@ if (storage == null) {
        }
 					// Create the reasoner for the consistency check by using
 					// the server and-point
-					KReSCreateReasoner newreasoner = new KReSCreateReasoner(
+					CreateReasoner newreasoner = new CreateReasoner(
 							inputowl, new URL(owllink_endpoint));
 					// Prepare and start the reasoner to classify ontology's
 					// resources
-					KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+					RunReasoner reasoner = new RunReasoner(newreasoner
 							.getReasoner());
 
 					// Create a new OWLOntology model where to put the inferred
@@ -77,13 +77,13 @@ public class Classify {
 
     /**
-     * To get the KReSRuleStore where are stored the rules and the recipes
+     * To get the RuleStoreImpl where are stored the rules and the recipes
      *
 	 * @param servletContext

Modified: incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/ConsistencyCheck.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/ConsistencyCheck.java?rev=1085388&r1=1085387&r2=1085388&view=diff
==============================================================================
--- incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Enrichment.java (original)
+++ incubator/stanbol/trunk/kres/reasoners/web/src/main/java/org/apache/stanbol/reasoners/web/Enrichment.java Fri Mar 25 14:15:32 2011
@@ -26,23 +26,23 @@ import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
 
 import org.apache.clerezza.rdf.core.access.TcManager;
-import org.apache.stanbol.ontologymanager.ontonet.api.KReSONManager;
+import org.apache.stanbol.ontologymanager.ontonet.api.ONManager;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.OntologyScope;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.OntologySpace;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.ScopeRegistry;
 import org.apache.stanbol.ontologymanager.ontonet.api.ontology.SessionOntologySpace;
-import org.apache.stanbol.ontologymanager.ontonet.impl.ONManager;
+import org.apache.stanbol.ontologymanager.ontonet.impl.ONManagerImpl;
 import org.apache.stanbol.ontologymanager.ontonet.impl.ontology.OntologyStorage;
-import org.apache.stanbol.reasoners.base.commands.KReSCreateReasoner;
-import org.apache.stanbol.reasoners.base.commands.KReSRunReasoner;
-import org.apache.stanbol.reasoners.base.commands.KReSRunRules;
-import org.apache.stanbol.rules.base.api.KReSRule;
+import org.apache.stanbol.reasoners.base.commands.CreateReasoner;
+import org.apache.stanbol.reasoners.base.commands.RunReasoner;
+import org.apache.stanbol.reasoners.base.commands.RunRules;
+import org.apache.stanbol.rules.base.api.Rule;
 import org.apache.stanbol.rules.base.api.NoSuchRecipeException;
 import org.apache.stanbol.rules.base.api.RuleStore;
-import org.apache.stanbol.rules.base.api.util.KReSRuleList;
-import org.apache.stanbol.rules.manager.KReSKB;
-import org.apache.stanbol.rules.manager.changes.KReSRuleStore;
-import org.apache.stanbol.rules.manager.parse.KReSRuleParser;
+import org.apache.stanbol.rules.base.api.util.RuleList;
+import org.apache.stanbol.rules.manager.KB;
+import org.apache.stanbol.rules.manager.changes.RuleStoreImpl;
+import org.apache.stanbol.rules.manager.parse.RuleParserImpl;
 import org.semanticweb.owlapi.apibinding.OWLManager;
 import org.semanticweb.owlapi.model.AddImport;
 import org.semanticweb.owlapi.model.IRI;
@@ -76,13 +76,13 @@ public class Enrichment {
     private OWLOntology inputowl;
     private OWLOntology scopeowl;
 
-	protected KReSONManager onm;
+	protected ONManager onm;
 	protected OntologyStorage storage;
 
 	private Logger log = LoggerFactory.getLogger(getClass());
 
     /**
      * To get the KReSRuleStore where are stored the rules and the recipes
      *
 	 * @param servletContext
 	 *            {To get the context where the REST service is running.}
@@ -92,8 +92,8 @@ public class Enrichment {
 		this.kresRuleStore = (RuleStore) servletContext
 				.getAttribute(RuleStore.class.getName());
 		// Retrieve the ontology network manager
-		this.onm = (KReSONManager) servletContext
-				.getAttribute(KReSONManager.class.getName());
+		this.onm = (ONManager) servletContext
+				.getAttribute(ONManager.class.getName());
 //      this.storage = (OntologyStorage) servletContext
 //      .getAttribute(OntologyStorage.class.getName());
 // Contingency code for missing components follows.
@@ -104,7 +104,7 @@ public class Enrichment {
 if (onm == null) {
     log
             .warn("No KReSONManager in servlet context. Instantiating manually...");
-    onm = new ONManager(new TcManager(), null,
+    onm = new ONManagerImpl(new TcManager(), null,
             new Hashtable<String, Object>());
 }
 this.storage = onm.getOntologyStore();
@@ -115,7 +115,7 @@ if (storage == null) {
        if (kresRuleStore == null) {
 			log
 					.warn("No KReSRuleStore with stored rules and recipes found in servlet context. Instantiating manually with default values...");
-			this.kresRuleStore = new KReSRuleStore(onm,
+			this.kresRuleStore = new RuleStoreImpl(onm,
 					new Hashtable<String, Object>(), "");
 			log
 					.debug("PATH TO OWL FILE LOADED: "
@@ -134,7 +134,7 @@ if (storage == null) {
 			throws NoSuchRecipeException {
 
 		// FIXME: why the heck is this method re-instantiating a rule store?!?
-		RuleStore store = new KReSRuleStore(onm,
+		RuleStore store = new RuleStoreImpl(onm,
 				new Hashtable<String, Object>(), owl);
         Model jenamodel = ModelFactory.createDefaultModel();
 
@@ -170,11 +170,11 @@ if (storage == null) {
 		}
 
 	//"ProvaParent = <http://www.semanticweb.org/ontologies/2010/6/ProvaParent.owl#> . rule1[ has(ProvaParent:hasParent, ?x, ?y) . has(ProvaParent:hasBrother, ?y, ?z) -> has(ProvaParent:hasUncle, ?x, ?z) ]");
-        KReSKB kReSKB = KReSRuleParser.parse(kReSRules);
-        KReSRuleList listrules = kReSKB.getkReSRuleList();
-        Iterator<KReSRule> iterule = listrules.iterator();
+        KB kReSKB = RuleParserImpl.parse(kReSRules);
+        RuleList listrules = kReSKB.getkReSRuleList();
+        Iterator<Rule> iterule = listrules.iterator();
         while(iterule.hasNext()){
-            KReSRule singlerule = iterule.next();
+            Rule singlerule = iterule.next();
             Resource resource = singlerule.toSWRL(jenamodel);
         }
 
@@ -360,7 +360,7 @@ if (storage == null) {
 
 						// Create a reasoner to run rules contained in the
 						// recipe
-						KReSRunRules rulereasoner = new KReSRunRules(swrlmodel,
+						RunRules rulereasoner = new RunRules(swrlmodel,
 								inputowl);
 						// Run the rule reasoner to the input RDF with the added
 						// top-ontology
@@ -368,11 +368,11 @@ if (storage == null) {
        }    
        
             //Create the reasoner for the enrichment
-					KReSCreateReasoner newreasoner = new KReSCreateReasoner(
+					CreateReasoner newreasoner = new CreateReasoner(
 							inputowl);
 					// Prepare and start the reasoner to enrich ontology's
 					// resources
-					KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+					RunReasoner reasoner = new RunReasoner(newreasoner
 							.getReasoner());
 
 					// Create a new OWLOntology model where to put the inferred
@@ -412,7 +412,7 @@ if (storage == null) {
          Model swrlmodel = fromRecipeToModel(recipeowl);
 						// Create a reasoner to run rules contained in the
 						// recipe by using the server and-point
-						KReSRunRules rulereasoner = new KReSRunRules(swrlmodel,
+						RunRules rulereasoner = new RunRules(swrlmodel,
 								inputowl, new URL(owllink_endpoint));
 						// Run the rule reasoner to the input RDF with the added
 						// top-ontology
@@ -425,11 +425,11 @@ if (storage == null) {
 							.createOntology(inputowl.getOntologyID());
 
          //Create the reasoner for the enrichment
-					KReSCreateReasoner newreasoner = new KReSCreateReasoner(
+					CreateReasoner newreasoner = new CreateReasoner(
 							inputowl, new URL(owllink_endpoint));
 					// Prepare and start the reasoner to enrich ontology's
 					// resources
-					KReSRunReasoner reasoner = new KReSRunReasoner(newreasoner
+					RunReasoner reasoner = new RunReasoner(newreasoner
 							.getReasoner());
 
          //Initial input axioms count
@@ -76,13 +76,13 @@ public class Enrichment {
 
     /**
-     * To get the KReSRuleStore where are stored the rules and the recipes
+     * To get the RuleStoreImpl where are stored the rules and the recipes
      *
 	 * @param servletContext